@@ -14,6 +14,7 @@ import json
 from difflib import SequenceMatcher
 from unidecode import unidecode_expect_ascii
 import PIL
+from tesserocr import PyTessBaseAPI, RIL, iterate_level, PSM, OEM
 
 # print("Hello sheet music")
 
@@ -170,6 +171,23 @@ def parse_pytesseract_data(data):
 	])
 
 
+class TesserocrDetections(Detections):
+	def __init__(self, api, level=None):
+		self.api = api
+		self.level = level
+	
+	def text(self):
+		if self.level is not None:
+			return self.api.GetUTF8Text(self.level).strip("\n")
+		return self.api.GetUTF8Text().strip("\n")
+	
+	def blocks(self):
+		iterator = self.api.GetIterator()
+		level = RIL.BLOCK
+		for block in iterate_level(iterator, level):
+			yield TesserocrDetections(block, level=level)
+
+
 class SubstringSequenceMatcher(SequenceMatcher):
 	def is_rougly_substring(self, substring, fullstring, ratio=0.95):
 		substring = unidecode_expect_ascii(substring.lower())
