@@ -29,6 +29,8 @@ class PdfPredictor():
         log_stream=sys.stdout,
         crop_to_top=False,
         crop_to_left=True,
+        full_score_threshold=3,
+        full_score_label="Full score",
         ):
         self.instruments = get_instruments_dict(
             instruments=instruments,
@@ -44,6 +46,8 @@ class PdfPredictor():
         self.crop_to_top = crop_to_top
         self.crop_to_left = crop_to_left
         self.crop = crop_to_top or crop_to_left
+        self.full_score_threshold = full_score_threshold
+        self.full_score_label = full_score_label
     
     def log(self, *msg):
         if self.log_stream is None:
@@ -84,6 +88,9 @@ class PdfPredictor():
                 parts = list(predict_parts(detections, self.instruments))
                 self.log(f"done in {timer} seconds")
                 self.log("parts:", [part for part in parts])
+                if len(parts) >= self.full_score_threshold:
+                    self.log("recognized as full score")
+                    parts = [(self.full_score_label, None, [self.full_score_label])]
                 for j, (name, part_number, instruments) in enumerate(parts):
                     if lastPartName == name:
                         continue
